@@ -13,7 +13,7 @@ from urllib.request import urlopen
 from urllib.error import HTTPError
 
 
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
 
 def sign_csr(account_key, csr, email=None):
@@ -29,8 +29,8 @@ def sign_csr(account_key, csr, email=None):
     :rtype: string
 
     """
-    CA = "https://acme-staging-v02.api.letsencrypt.org"
-    #CA = "https://acme-v02.api.letsencrypt.org"
+    #CA = "https://acme-staging-v02.api.letsencrypt.org"
+    CA = "https://acme-v02.api.letsencrypt.org"
     DIRECTORY = json.loads(urlopen(CA + "/directory").read().decode('utf8'))
 
     def _b64(b):
@@ -351,12 +351,12 @@ $ openssl genrsa -aes256 4096 > user.key
 $ openssl rsa -in user.key -pubout > user.pub
 $ openssl genrsa -aes256 4096 > domain.key
 $ openssl req -new -sha256 -key domain.key -subj "/CN=example.com" > domain.csr
-$ python3 acmens.py --account-key user.key --email user@example.com --csr domain.csr > signed.crt
+$ acmens --account-key user.key --email user@example.com --csr domain.csr > signed.crt
 --------------
 
 Example: Revoking a signed certificate:
 --------------
-$ python3 acmens.py --revoke --account-key user.key --crt domain.crt
+$ acmens --revoke --account-key user.key --crt domain.crt
 --------------
 """);
     parser.add_argument("--revoke", action="store_true", help="Revoke a signed certificate")
